# Introduction

## What is ADRIA.jl?

ADRIA is a decision support platform for informing reef restoration and adaptation interventions
through scenario exploration and analysis, decision heuristics (MCDA), alongside a small coral ecosystem model.

Among the most common usecases are:

- Running a number of scenarios under different environmental and intervention conditions (see [Loading a Domain](@ref), [Generating scenarios](@ref) and [Running scenarios](@ref));
- Extracting metrics for each scenario and timestep such as coral cover, shelter volume or number of juveniles (see [Metrics](@ref));
- Using these metrics to perform a range of analyses like time series clustering (grouping together scenarios with similar temporal behaviour; see [Analysis](@ref));
- Using the visualization tools to plot some of the mentioned metrics or analysis (see [Analysis](@ref));

More details about each of these can be found in the next sections.

## Troubleshooting F.A.Q

ADRIA.jl is under active development and from time to time issues may arise.
Here are some answers to some issues encountered.

**Q. I get this warning when trying to load pre-existing results:**
  `Results were produced with a different version of ADRIA (v0.x.x). The installed version of ADRIA is: v0.y.y. Errors may occur when analyzing data.`
  (where `x` and `y` are different numbers).

**A.** The result set being loaded were generated by a different version of ADRIA, and in a possibly incompatible format.
  Sometimes, results may still be produced/analyzed as normal. In other times, ADRIA.jl or the expected metadata in the result set may have changed
  leading to errors when conducting analyses.

  Either go back to the version indicated, or re-run the scenarios to obtain results in the updated format.

**Q. I get an error or warning about an `ENV` variable not being found or set.**

**A.** Double check the configuration settings in `config.toml` (see above).

**Q. How do I run my own scenarios?**

**A.** Scenarios are defined in a CSV file (with parameter values in columns, so that each row defines a scenario).

- See the `example_scenarios.csv` file in the `examples` directory for an idea of what this looks like.
- See `parameters.jl` file in the `examples` directory on how to extract the model specification and parameter table for a given domain.
- See also the `running_scenarios.jl` example script which showcases how to run such a file for a given study area.
